#!/bin/sh

# Setting bash options
set -o errexit
set -o nounset
set -o pipefail

# Getting full path to current script
prg=$0
if [ ! -e "$prg" ]; then
  case $prg in
    (*/*) exit 1;;
    (*) prg=$(command -v -- "$prg") || exit;;
  esac
fi

# Setting variables
FL_THIS_DIR=$(
  cd -P -- "$(dirname -- "$prg")" && pwd -P
) || exit
FL_LIB_DIR="${FL_THIS_DIR}/lib"
FL_FLINSEY_VERSION="1.0"

# Loading libraries
if [ ! -d "${FL_LIB_DIR}" ];
then
	echo "ERROR: library directory does not exist. F-Linsey was not properly installed."
	exit 1
fi

# Including important library files
source "${FL_LIB_DIR}/errors.sh"
source "${FL_LIB_DIR}/handle_help.sh"
source "${FL_LIB_DIR}/modules.sh"

# Checking if modules directory exist
FL_MODULE_DIR="${FL_THIS_DIR}/modules"
if [ ! -d "${FL_MODULE_DIR}" ]
then
	fl1_err_no_modules
fi

# Parsing command line

# Checking if parameters passed
if [ $# -lt 1 ]
then
	fl1_handle_help
fi

# Reacting to command
FL_COMMAND=$1
shift

# Checking if command handler exists
if [ ! -f "${FL_LIB_DIR}/handle_${FL_COMMAND}.sh" ]
then
	fl1_err_unknown_command $FL_COMMAND
fi

# Loading command handler file and calling handler
source "${FL_LIB_DIR}/handle_${FL_COMMAND}.sh"
fl1_handle_${FL_COMMAND} $*

echo "F_Linsey finished."